Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: tools-webrtc/valgrind/webrtc_tests.py

Issue 2578093002: Move tools/valgrind-webrtc -> tools-webrtc/valgrind (Closed)
Patch Set: Sorted presubmit pylint exclusion Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools-webrtc/valgrind/valgrind-webrtc.gni ('k') | tools-webrtc/valgrind/webrtc_tests.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools-webrtc/valgrind/webrtc_tests.py
diff --git a/tools/valgrind-webrtc/webrtc_tests.py b/tools-webrtc/valgrind/webrtc_tests.py
similarity index 94%
rename from tools/valgrind-webrtc/webrtc_tests.py
rename to tools-webrtc/valgrind/webrtc_tests.py
index aacf49782a0ee330541fc77df49279abd79eba0b..627025cd75d2413aaf688bf943c2d5dcda08af62 100755
--- a/tools/valgrind-webrtc/webrtc_tests.py
+++ b/tools-webrtc/valgrind/webrtc_tests.py
@@ -66,16 +66,15 @@ class WebRTCTest(chrome_tests.ChromeTests):
# this script's location. If Mac or Windows is executing, additional
# platform specific files have also been added.
# Since only the ones located below this directory are added, we must also
# add the ones maintained by Chrome, located in ../valgrind.
# The idea is to look for --suppression arguments in the cmd list and add a
# modified copy of each suppression file, for the corresponding file in
- # ../valgrind. If we would simply replace 'valgrind-webrtc' with 'valgrind'
- # we may produce invalid paths if other parts of the path contain that
- # string. That's why the code below only replaces the end of the path.
+ # ../../tools/valgrind.
script_dir = path_utils.ScriptDir()
- old_base, _ = os.path.split(script_dir)
- new_dir = os.path.join(old_base, 'valgrind')
+ checkout_src = os.path.abspath(os.path.join(script_dir, os.pardir,
+ os.pardir))
+ new_dir = os.path.join(checkout_src, 'tools', 'valgrind')
add_suppressions = []
for token in cmd:
if '--suppressions' in token:
@@ -66,16 +66,15 @@ class WebRTCTest(chrome_tests.ChromeTests):
# platform specific files have also been added.
# Since only the ones located below this directory are added, we must also
- # add the ones maintained by Chrome, located in ../valgrind.
+ # add the ones maintained by Chrome, located in ../../tools/valgrind.
# The idea is to look for --suppression arguments in the cmd list and add a
# modified copy of each suppression file, for the corresponding file in
« no previous file with comments | « tools-webrtc/valgrind/valgrind-webrtc.gni ('k') | tools-webrtc/valgrind/webrtc_tests.sh » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698